==> instagram_field-8.x-1.2.tar.gz: instagram_field/src/Plugin/Field/FieldFormatter/InstagramFieldFormatter.php <==
<?php

namespace Drupal\instagram_field\Plugin\Field\FieldFormatter;

use Drupal\Core\Field\FormatterBase;
use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Component\Serialization\Json;

/**
 * Plugin implementation of the 'instagramfield_link' formatter.
 *
 * @FieldFormatter(
 *   id = "instagramfield_formatter",
 *   label = @Translation("Instagram recent"),
 *   field_types = {
 *     "instagramfield"
 *   }
 * )
 */
class InstagramFieldFormatter extends FormatterBase {

  const THUMBS_DIRECTORY = 'public://instagram_thumbnails';

  /**
   * Get recent posts from instagram.
   */
  public function viewElements(FieldItemListInterface $items, $langcode) {
    $config = \Drupal::config('config.instagram_field');
    $client = \Drupal::httpClient();
    $request = $client->request('GET',
      'https://api.instagram.com/v1/users/self/media/recent/', [
        'query' => [
          'access_token' => $config->get('accesstoken'),
          'count' => count($items),
        ],
      ]
    );
    $result = json::decode($request->getBody());
    foreach ($result['data'] as $key => $value) {
      if (isset($items[$key])) {
        $this->loadImage($value['id'], $value['images'][$config
          ->get('imageresolution')]['url']);
        $items[$key]->setValue([
          'instagramid' => $value['id'],
          'instagramlink' => $value['link'],
        ], TRUE);
        $items[$key]->getEntity()->save();
      }
    }

    $element = [];
    foreach ($items as $delta => $item) {
      if (strlen($items[$delta]->getValue()['instagramid']) > 1) {
        $element[$delta] = [
          '#type' => 'html_tag',
          '#tag' => 'A',
          '#attributes' => [
            'href' => $items[$delta]->getValue()['instagramlink'],
          ],
          'content' => [
            'img' => [
              '#type' => 'html_tag',
              '#tag' => 'img',
              '#attributes' => [
                'src' => file_create_url(self::THUMBS_DIRECTORY .
                  '/' . $items[$delta]->getValue()['instagramid']
                  . '.jpg'),
              ],
            ],
          ],
          '#cache' => [
            'max-age' => $config->get('cachetime') * 60,
          ],
        ];
      }
    }
    return $element;
  }

  /**
   * Load image from disk or download it from instagram.
   */
  private function loadImage($imageid, $url) {
    $local_uri = self::THUMBS_DIRECTORY . '/' . $imageid . '.jpg';
    if (!file_exists($local_uri)) {
      file_prepare_directory(self::THUMBS_DIRECTORY, FILE_CREATE_DIRECTORY);
      try {
        $thumbnail = \Drupal::httpClient()->request('GET', $url);
        file_unmanaged_save_data((string) $thumbnail->getBody(),
          $local_uri);
      }
      catch (\Exception $e) {

      }
    }
  }

}

==> instagram_field-8.x-1.3.tar.gz: instagram_field/src/Plugin/Field/FieldFormatter/InstagramFieldFormatter.php <==
<?php

namespace Drupal\instagram_field\Plugin\Field\FieldFormatter;

use Drupal\Core\Field\FormatterBase;
use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Component\Serialization\Json;

/**
 * Plugin implementation of the 'instagramfield_link' formatter.
 *
 * @FieldFormatter(
 *   id = "instagramfield_formatter",
 *   label = @Translation("Instagram recent"),
 *   field_types = {
 *     "instagramfield"
 *   }
 * )
 */
class InstagramFieldFormatter extends FormatterBase {

  const THUMBS_DIRECTORY = 'public://instagram_thumbnails';

  /**
   * Get recent posts from instagram.
   */
  public function viewElements(FieldItemListInterface $items, $langcode) {
    $config = \Drupal::config('config.instagram_field');
    $client = \Drupal::httpClient();
    $request = $client->request('GET',
      'https://api.instagram.com/v1/users/self/media/recent/', [
        'query' => [
          'access_token' => $config->get('accesstoken'),
          'count' => count($items),
        ],
      ]
    );
    $result = json::decode($request->getBody());
    foreach ($result['data'] as $key => $value) {
      if (isset($items[$key])) {
        $this->loadImage($value['id'], $value['images'][$config
          ->get('imageresolution')]['url']);
        $items[$key]->setValue([
          'instagramid' => $value['id'],
          'instagramlink' => $value['link'],
        ], TRUE);
        $items[$key]->getEntity()->save();
      }
    }

    $element = [];
    foreach ($items as $delta => $item) {
      if (strlen($items[$delta]->getValue()['instagramid']) > 1) {
        $element[$delta] = [
          '#type' => 'html_tag',
          '#tag' => 'A',
          '#attributes' => [
            'href' => $items[$delta]->getValue()['instagramlink'],
          ],
          'content' => [
            'img' => [
              '#type' => 'html_tag',
              '#tag' => 'img',
              '#attributes' => [
                'src' => file_create_url(self::THUMBS_DIRECTORY .
                  '/' . $items[$delta]->getValue()['instagramid']
                  . '.jpg'),
              ],
            ],
          ],
          '#cache' => [
            'max-age' => $config->get('cachetime') * 60,
          ],
        ];
      }
    }
    return $element;
  }

  /**
   * Load image from disk or download it from instagram.
   */
  private function loadImage($imageid, $url) {
    $directory = self::THUMBS_DIRECTORY;
    $local_uri = $directory . '/' . $imageid . '.jpg';
    if (!file_exists($local_uri)) {
      file_prepare_directory($directory, FILE_CREATE_DIRECTORY);
      try {
        $thumbnail = \Drupal::httpClient()->request('GET', $url);
        file_unmanaged_save_data((string) $thumbnail->getBody(),
          $local_uri);
      }
      catch (\Exception $e) {

      }
    }
  }

}
